@@ -1,11 +1,13 @@
-from samtranslator.model.naming import GeneratedLogicalId
+from typing import Any, Dict, Optional, Type
+
 from samtranslator.plugins.api.implicit_api_plugin import ImplicitApiPlugin
 from samtranslator.public.swagger import SwaggerEditor
-from samtranslator.public.exceptions import InvalidEventException
 from samtranslator.public.sdk.resource import SamResourceType, SamResource
+from samtranslator.sdk.template import SamTemplate
+from samtranslator.validator.value_validator import sam_expect
 
 
-class ImplicitRestApiPlugin(ImplicitApiPlugin):
+class ImplicitRestApiPlugin(ImplicitApiPlugin[Type[SwaggerEditor]]):
     """
     This plugin provides Implicit API shorthand syntax in the SAM Spec.
     https://github.com/awslabs/serverless-application-model/blob/master/versions/2016-10-31.md#api
@@ -24,29 +26,24 @@ class ImplicitRestApiPlugin(ImplicitApiPlugin):
 
     * API Event Source (In Core Translator): ONLY adds the Lambda Integration ARN to appropriate method/path
                                              in Swagger. Does **not** configure the API by any means.
-
     """
 
-    def __init__(self) -> None:
-        """
-        Initialize the plugin
-        """
-        super(ImplicitRestApiPlugin, self).__init__(ImplicitRestApiPlugin.__name__)
+    API_ID_EVENT_PROPERTY = "RestApiId"
+    IMPLICIT_API_LOGICAL_ID = "ServerlessRestApi"
+    IMPLICIT_API_CONDITION = "ServerlessRestApiCondition"
+    API_EVENT_TYPE = "Api"
+    SERVERLESS_API_RESOURCE_TYPE = SamResourceType.Api.value
+    EDITOR_CLASS = SwaggerEditor
 
-    def _setup_api_properties(self):  # type: ignore[no-untyped-def]
-        """
-        Sets up properties that are distinct to this plugin
-        """
-        self.implicit_api_logical_id = GeneratedLogicalId.implicit_api()  # type: ignore[no-untyped-call]
-        self.implicit_api_condition = "ServerlessRestApiCondition"
-        self.api_event_type = "Api"
-        self.api_type = SamResourceType.Api.value
-        self.api_id_property = "RestApiId"
-        self.editor = SwaggerEditor
-
-    def _process_api_events(  # type: ignore[no-untyped-def]
-        self, function, api_events, template, condition=None, deletion_policy=None, update_replace_policy=None
-    ):
+    def _process_api_events(
+        self,
+        function: SamResource,
+        api_events: Dict[str, Dict[str, Any]],
+        template: SamTemplate,
+        condition: Optional[str] = None,
+        deletion_policy: Optional[str] = None,
+        update_replace_policy: Optional[str] = None,
+    ) -> None:
         """
         Actually process given API events. Iteratively adds the APIs to Swagger JSON in the respective Serverless::Api
         resource from the template
@@ -57,84 +54,40 @@ class ImplicitRestApiPlugin(ImplicitApiPlugin):
         :param str condition: optional; this is the condition that is on the function with the API event
         """
 
-        for logicalId, event in api_events.items():
+        for event_id, event in api_events.items():
 
             event_properties = event.get("Properties", {})
             if not event_properties:
                 continue
 
-            if not isinstance(event_properties, dict):
-                raise InvalidEventException(
-                    logicalId,
-                    "Event 'Properties' must be an Object. If you're using YAML, this may be an indentation issue.",
-                )
+            sam_expect(event_properties, event_id, "", is_sam_event=True).to_be_a_map("Properties should be a map.")
 
             self._add_implicit_api_id_if_necessary(event_properties)  # type: ignore[no-untyped-call]
 
-            api_id = self._get_api_id(event_properties)  # type: ignore[no-untyped-call]
-            try:
-                path = event_properties["Path"]
-                method = event_properties["Method"]
-            except KeyError as e:
-                raise InvalidEventException(logicalId, "Event is missing key {}.".format(e))
+            api_id, path, method = self._validate_api_event(event_id, event_properties)
+            self._update_resource_attributes_from_api_event(
+                api_id, path, method, condition, deletion_policy, update_replace_policy
+            )
 
-            if not isinstance(path, str):
-                raise InvalidEventException(logicalId, "Api Event must have a String specified for 'Path'.")
-            if not isinstance(method, str):
-                raise InvalidEventException(logicalId, "Api Event must have a String specified for 'Method'.")
+            self._add_api_to_swagger(event_id, event_properties, template)  # type: ignore[no-untyped-call]
 
-            # !Ref is resolved by this time. If it is not a string, we can't parse/use this Api.
-            if api_id and not isinstance(api_id, str):
-                raise InvalidEventException(
-                    logicalId, "Api Event's RestApiId must be a string referencing an Api in the same template."
-                )
-
-            api_dict_condition = self.api_conditions.setdefault(api_id, {})
-            method_conditions = api_dict_condition.setdefault(path, {})
-            method_conditions[method] = condition
-
-            api_dict_deletion = self.api_deletion_policies.setdefault(api_id, set())
-            api_dict_deletion.add(deletion_policy)
-
-            api_dict_update_replace = self.api_update_replace_policies.setdefault(api_id, set())
-            api_dict_update_replace.add(update_replace_policy)
-
-            self._add_api_to_swagger(logicalId, event_properties, template)  # type: ignore[no-untyped-call]
-
-            api_events[logicalId] = event
+            api_events[event_id] = event
 
         # We could have made changes to the Events structure. Write it back to function
         function.properties["Events"].update(api_events)
 
-    def _add_implicit_api_id_if_necessary(self, event_properties):  # type: ignore[no-untyped-def]
-        """
-        Events for implicit APIs will *not* have the RestApiId property. Absence of this property means this event
-        is associated with the Serverless::Api ImplicitAPI resource. This method solifies this assumption by adding
-        RestApiId property to events that don't have them.
-
-        :param dict event_properties: Dictionary of event properties
-        """
-        if "RestApiId" not in event_properties:
-            event_properties["RestApiId"] = {"Ref": self.implicit_api_logical_id}
-
-    def _generate_implicit_api_resource(self):  # type: ignore[no-untyped-def]
+    def _generate_implicit_api_resource(self) -> Dict[str, Any]:
         """
         Uses the implicit API in this file to generate an Implicit API resource
         """
         return ImplicitApiResource().to_dict()
 
-    def _get_api_definition_from_editor(self, editor):  # type: ignore[no-untyped-def]
+    def _get_api_definition_from_editor(self, editor: SwaggerEditor) -> Dict[str, Any]:
         """
         Helper function to return the OAS definition from the editor
         """
         return editor.swagger
 
-    def _get_api_resource_type_name(self):  # type: ignore[no-untyped-def]
-        """
-        Returns the type of API resource
-        """
-        return "AWS::Serverless::Api"
-
 
 class ImplicitApiResource(SamResource):
     """
@@ -159,4 +112,4 @@ class ImplicitApiResource(SamResource):
             },
         }
 
-        super(ImplicitApiResource, self).__init__(resource)
+        super().__init__(resource)
