@@ -1,3 +1,6 @@
+from samtranslator.model import Resource
+from typing import Dict, Any
+
 do_not_verify = {
     # type_after_transform: type_before_transform
     "AWS::Lambda::Function": "AWS::Serverless::Function",
@@ -15,7 +18,7 @@ do_not_verify = {
 }
 
 
-def verify_unique_logical_id(resource, existing_resources):
+def verify_unique_logical_id(resource: Resource, existing_resources: Dict[str, Any]) -> bool:
     # new resource logicalid exists in the template before transform
     if resource.logical_id is not None and resource.logical_id in existing_resources:
         # new resource logicalid is in  the do_not_resolve list
